==> wowit-0.3.106.tar.gz: lib/sqlService.dart <==
import 'dart:convert';

import 'package:flutter/cupertino.dart';
import 'package:http/http.dart' as http;
import 'package:wowit/common.dart';
import 'package:wowit/methods.dart';

class SQLService {
  static Future<Map<String, List<Map<String, Object>>>> execute(String query,
      {Map<String, Object> params}) async {
    var queryParameters = {
      'query': query,
    };
    if (params == null) {
      params = {};
    }
    if (!params.containsKey('uid') && !params.containsKey('@uid')) {
      params['uid'] = Common.uid;
    }
    if (!params.containsKey('languageId') &&
        !params.containsKey('@languageId')) {
      params['languageId'] = Common.languageId;
    }
    queryParameters['jParam'] = jsonEncode(params);
    Map<
        String, // table namme
        List< // list row -> data tabl
            Map<String, Object> //data row
            >> retVal = {};
    try {
      var response =
          await http.post(Methods.getURI('/data/exec'), body: queryParameters);
      if (response.statusCode == 200) {
        if (response.body == "") {
          print('response.body is empty');
          return retVal;
        }
        Map<String, dynamic> jsonData =
            json.decode(response.body); //--> return data set
        jsonData.forEach((key, value) {
          List<dynamic> table = value;
          List<Map<String, Object>> rsTable = [];
          for (int i = 0; i < table.length; i++) {
            rsTable.add(table[i]);
          }
          retVal[key] = rsTable;
        });
      } else {
        print('SQLService.execute with ' +
            query +
            ' reponse status code = ' +
            response.statusCode.toString());
      }
    } catch (e) {
      print('SQLService.execute with exception:  ' + e.toString());
    }

    if (retVal.length > 0 && retVal.containsKey('Exception')) {
      var dataException = Methods.getList(retVal, 'Exception');
      if (dataException.length > 0 && dataException[0].containsKey('Message')) {
        var exception = Methods.getString(dataException[0], 'Message');
        if (exception != "") {
          print(
              "==================>[Exception]<==================\n==================> Query:" +
                  query +
                  "\n==================> Parameter:" +
                  params.toString() +
                  "\n==================> Message:" +
                  exception.toString());
        }
      }
    }

    return retVal;
  }

  static void logView(
      {String query = 'spLogView',
      @required int viewID,
      @required int dataID}) {
    SQLService.execute(query,
        params: {'@userID': Common.uid, '@idView': viewID, '@idData': dataID});
  }

  static void logLike(
      {String query = 'spLogLike',
      @required int idLoai,
      @required int idItem,
      @required bool isLike}) {
    SQLService.execute(query, params: {
      '@userID': Common.uid,
      '@idView': idLoai,
      '@idData': idItem,
      '@isLike': isLike
    });
  }

  static void logFollow(
      {String query = 'spLogFollow',
      @required int idLoai,
      @required int idItem,
      @required bool isFollow}) {
    SQLService.execute(query, params: {
      '@userID': Common.uid,
      '@idView': idLoai,
      '@idData': idItem,
      '@isFollow': isFollow
    });
  }
}

==> wowit-0.3.161.tar.gz: lib/sqlService.dart <==
import 'dart:convert';

import 'package:flutter/foundation.dart';
import 'package:http/http.dart' as http;
import 'package:wowit/common.dart';
import 'package:wowit/methods.dart';

class SQLService {
  static Future<Map<String, List<Map<String, Object>>>> execute(String query,
      {Map<String, Object> params}) async {
    if (params == null) {
      params = {};
    }
    if (!params.containsKey('uid') && !params.containsKey('@uid')) {
      params['uid'] = Common.uid;
    }

    if (kDebugMode) {
      if (!params.containsKey('kDebugMode') &&
          !params.containsKey('@kDebugMode')) {
        params['kDebugMode'] = kDebugMode;
      }
    }

    if (!params.containsKey('languageId') &&
        !params.containsKey('@languageId')) {
      params['languageId'] = Common.languageId;
    }
    var queryParameters = {
      'query': query,
      'jParam': jsonEncode(params),
    };
    print("execute query: " +
        query +
        ", jParam jsonEncode" +
        queryParameters.toString());
    Map<
        String, // table namme
        List< // list row -> data tabl
            Map<String, Object> //data row
            >> retVal = {};
    try {
      var response =
          await http.post(Methods.getURI('/data/exec'), body: queryParameters);
      if (response.statusCode == 200) {
        if (response.body == "") {
          print("execute query: " + query + '  response.body is empty');
          return retVal;
        }
        Map<String, dynamic> jsonData =
            json.decode(response.body); //--> return data set
        jsonData.forEach((key, value) {
          List<dynamic> table = value;
          List<Map<String, Object>> rsTable = [];
          for (int i = 0; i < table.length; i++) {
            rsTable.add(table[i]);
          }
          retVal[key] = rsTable;
        });
        print("execute query: " +
            query +
            ', result length: ' +
            retVal.length.toString());
      } else {
        print('SQLService.execute with ' +
            query +
            ' reponse status code = ' +
            response.statusCode.toString());
      }
    } catch (e) {
      print('SQLService.execute with exception:  ' + e.toString());
    }

    if (retVal.length > 0 && retVal.containsKey('Exception')) {
      var dataException = Methods.getList(retVal, 'Exception');
      if (dataException.length > 0 && dataException[0].containsKey('Message')) {
        var exception = Methods.getString(dataException[0], 'Message');
        if (exception != "") {
          print(
              "==================>[Exception]<==================\n==================> Query:" +
                  query +
                  "\n==================> Parameter:" +
                  params.toString() +
                  "\n==================> Message:" +
                  exception.toString());
        }
      }
    }

    return retVal;
  }

  static void logView(
      {String query = 'spLogView',
      @required int viewID,
      @required int dataID}) {
    SQLService.execute(query,
        params: {'@userID': Common.uid, '@idView': viewID, '@idData': dataID});
  }

  static void logLike(
      {String query = 'spLogLike',
      @required int idLoai,
      @required int idItem,
      @required bool isLike}) {
    SQLService.execute(query, params: {
      '@userID': Common.uid,
      '@idView': idLoai,
      '@idData': idItem,
      '@isLike': isLike
    });
  }

  static void logFollow(
      {String query = 'spLogFollow',
      @required int idLoai,
      @required int idItem,
      @required bool isFollow}) {
    SQLService.execute(query, params: {
      '@userID': Common.uid,
      '@idView': idLoai,
      '@idData': idItem,
      '@isFollow': isFollow
    });
  }
}
